function y=mfilt1(s,k)
%MFILT1 performs median filtering of a 1-D signal.
%	Y=MFILT1(S,K)
% INPUT
%   S -  Input signal (must be a column vector)
%   K -  filter length (must be odd)
% OUTPUT
%   Y -  Output signal.
%

%   Rev 1.0     Oct. 05, 2001   Dmitiry Shutin <dshutin@inw.tugraz.at>
%   Rev 1.1     Oct. 06, 2002   Input variables test, paddarray bug corrected
%   Rev 1.2     Oct. 30, 2009   Daniel Arnitz <daniel.arnitz@tugraz.at>
%                               added typecast back to original class of input signal

% input parameter checks
if nargin<1
   y=0;
   return;
end
if nargin<2
   k=1;
end
if ( k/2==floor(k/2) )
   warning('Filter length parameter must be odd. K is increased by 1'); %#ok<WNTAG>
   k=k+1;
end

% make sure this works for all vector/matrix orientations and (numeric) classes
orig_size = size(s);
orig_type = class(s);
s = s(:);

% filtering
M=length(s);
l=(k-1)/2;
s=[zeros(l,1) ; s ; zeros(l,1)];
for i=1+l:M+l
   y(i-l,1)=median(s(i-l:i+l));
end

% reshape to original size and typecast to original class
y = feval(orig_type, reshape(y, orig_size));
